@@ -3,6 +3,7 @@
 #include "strikethrough.h"
 #include "table.h"
 #include "tagfilter.h"
+#include "tasklist.h"
 #include "registry.h"
 #include "plugin.h"
 
@@ -12,6 +13,7 @@ static int core_extensions_registration(cmark_plugin *plugin) {
                                          create_strikethrough_extension());
   cmark_plugin_register_syntax_extension(plugin, create_autolink_extension());
   cmark_plugin_register_syntax_extension(plugin, create_tagfilter_extension());
+  cmark_plugin_register_syntax_extension(plugin, create_tasklist_extension());
   return 1;
 }
 
